@@ -75,7 +75,7 @@ def validate_tree(G, results):
         started = results[node].metadata.started
         for parent in G.predecessors(node):
             finished = results[parent].metadata.completed
-            assert started > finished, "%s should have happened after %s" % (
+            assert started > finished, "{} should have happened after {}".format(
                 node,
                 parent,
             )
@@ -89,8 +89,8 @@ def main(nodes, edges):
     point at least slightly to the right if the graph is valid.
     """
     from matplotlib import pyplot as plt
-    from matplotlib.dates import date2num
     from matplotlib.cm import gist_rainbow
+    from matplotlib.dates import date2num
 
     print("building DAG")
     G = random_dag(nodes, edges)
